# yuenpycounts

`yuenpycounts` is a API to calculate word counts in a text file!

## Installation

Step1: Open the Mac terminal enter the command to get `PIP`

```bash
$ python3 get-pip.py
```

Step2: install `yuenpycounts` package

```bash
$ pip install yuenpycounts
```

## Usage

- pip install the package, import `yuenpycounts` package and then call `count_words()` function or `plot_words()` function.

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`yuenpycounts` was created by Yuen Yip Man. It is licensed under the terms of the MIT license.

## Credits

`yuenpycounts` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).

# yuenpycountsß
"Final version"
